/*
 *  OpenVPN-GUI -- A Windows GUI for OpenVPN.
 *
 *  Copyright (C) 2004 Mathias Sundman <mathias@nilings.se>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program (see the file COPYING included with this
 *  distribution); if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <windows.h>
#include "tray.h"


//POPUP MENU
HMENU hMenu;	// menu handle
HWND  hwnd;     // main window handle

NOTIFYICONDATA ni;


// Mouse clicks on tray
void OnNotifyTray(LPARAM lParam)
{
  POINT pt;				// point structure

  // Right click, show the menu
  switch(lParam) {
    case WM_RBUTTONDOWN: 
      GetCursorPos(&pt);		// get the cursors position
      SetForegroundWindow(hwnd);	// set the foreground window
      TrackPopupMenu(hMenu,TPM_RIGHTALIGN,pt.x,pt.y,0,hwnd,NULL);// track the popup
      break;
    case WM_LBUTTONDOWN:
      break; 
  }
  PostMessage(hwnd,WM_NULL,0,0);// post a null message
}


void OnDestroyTray()
{
  //Destroy popup menu
  DestroyMenu(hMenu);
	
  //Remove Icon from Tray
  Shell_NotifyIcon(NIM_DELETE, &ni);
}


//Initialize tray
void TRAY_Init(HWND hWnd)
{
    hwnd = hWnd;
    hMenu=CreatePopupMenu();
    CreateItemList(hMenu); 
    LoadAppIcon();
} 


//Create menu items
void CreateItemList(HMENU hMenu)
{
	
  // CREATE POPUP MENU ( on the fly )
  AppendMenu(hMenu,MF_STRING,IDM_CONNECT,IDM_TEXT_CONNECT);// append menu  
  AppendMenu(hMenu,MF_STRING,IDM_DISCONNECT,IDM_TEXT_DISCONNECT);// append menu  
  AppendMenu(hMenu,MF_SEPARATOR,0,0);// append menu
  AppendMenu(hMenu,MF_STRING ,IDM_CLOSE,IDM_TEXT_CLOSE);// append menu 

}


BOOL LoadAppIcon()
{
  // Load icon from resource
  HICON hIcon = (HICON)LoadImage(GetModuleHandle(NULL), MAKEINTRESOURCE(APP_ICON), 
                                                IMAGE_ICON, 0, 0, LR_DEFAULTCOLOR);
  if (hIcon) {
    SendMessage(hwnd, WM_SETICON, (WPARAM) (ICON_SMALL), (LPARAM) (hIcon));
    SendMessage(hwnd, WM_SETICON, (WPARAM) (ICON_BIG), (LPARAM) (hIcon));  //ALT+TAB icon
    return TRUE;
  }
  return FALSE;
}


void ShowTrayIcon()
{
  ni.cbSize = sizeof(ni);
  ni.uID = 0;
  lstrcpyn(ni.szTip, MSG_TIP, sizeof(ni.szTip)); 
  ni.hWnd = hwnd;
  ni.uFlags = NIF_MESSAGE | NIF_TIP | NIF_ICON; // We want to use icon, tip, and callback message
  ni.uCallbackMessage = WM_NOTIFYICONTRAY;      // Our custom callback message (WM_APP + 1)
    
     
  //Load selected icon
  ni.hIcon = (HICON)LoadIcon((HINSTANCE)GetWindowLong(hwnd, GWL_HINSTANCE), 
                                                       MAKEINTRESOURCE(APP_ICON));	

  Shell_NotifyIcon(NIM_ADD, &ni);       
}
